Trait WrappingShr
trait WrappingShr: Sized + Shr<usize, Output = Self>
Performs a right shift that does not panic.
Required Methods
fn wrapping_shr(self: &Self, rhs: u32) -> SelfPanic-free bitwise shift-right; yields
self >> mask(rhs), wheremaskremoves any high order bits ofrhsthat would cause the shift to exceed the bitwidth of the type.use WrappingShr; let x: u16 = 0x8000; assert_eq!; assert_eq!; assert_eq!; assert_eq!;
Implementors
impl WrappingShr for isizeimpl WrappingShr for u32impl WrappingShr for u128impl WrappingShr for i32impl WrappingShr for u8impl WrappingShr for i128impl WrappingShr for u64impl WrappingShr for i8impl WrappingShr for i64impl WrappingShr for u16impl<T: WrappingShr> WrappingShr for Wrapping<T>impl WrappingShr for usizeimpl WrappingShr for i16