Trait CheckedDiv

trait CheckedDiv: Sized + Div<Self, Output = Self>

Performs division that returns None instead of panicking on division by zero and instead of wrapping around on underflow and overflow.

Required Methods

fn checked_div(self: &Self, v: &Self) -> Option<Self>

Divides two numbers, checking for underflow, overflow and division by zero. If any of that happens, None is returned.

Implementors