Trait CheckedShr

trait CheckedShr: Sized + Shr<u32, Output = Self>

Performs a right shift that returns None on shifts larger than or equal to the type width.

Required Methods

fn checked_shr(self: &Self, rhs: u32) -> Option<Self>

Checked shift right. Computes self >> rhs, returning None if rhs is larger than or equal to the number of bits in self.

use num_traits::CheckedShr;

let x: u16 = 0x8000;

assert_eq!(CheckedShr::checked_shr(&x, 0),  Some(0x8000));
assert_eq!(CheckedShr::checked_shr(&x, 1),  Some(0x4000));
assert_eq!(CheckedShr::checked_shr(&x, 15), Some(0x0001));
assert_eq!(CheckedShr::checked_shr(&x, 16), None);

Implementors