Trait num_traits::NumAssign[−][src]

pub trait NumAssign: Num + NumAssignOps { }

The trait for Num types which also implement assignment operators.

This is automatically implemented for types which implement the operators.

Implementors

impl<T> NumAssign for T where
    T: Num + NumAssignOps, 
[src]

Loading content...