Trait SaturatingAdd

trait SaturatingAdd: Sized + Add<Self, Output = Self>

Performs addition that saturates at the numeric bounds instead of overflowing.

Required Methods

fn saturating_add(self: &Self, v: &Self) -> Self

Saturating addition. Computes self + other, saturating at the relevant high or low boundary of the type.

Implementors