Trait SaturatingMul

trait SaturatingMul: Sized + Mul<Self, Output = Self>

Performs multiplication that saturates at the numeric bounds instead of overflowing.

Required Methods

fn saturating_mul(self: &Self, v: &Self) -> Self

Saturating multiplication. Computes self * other, saturating at the relevant high or low boundary of the type.

Implementors