Trait WrappingShl
trait WrappingShl: Sized + Shl<usize, Output = Self>
Performs a left shift that does not panic.
Required Methods
fn wrapping_shl(self: &Self, rhs: u32) -> SelfPanic-free bitwise shift-left; yields
self << mask(rhs), wheremaskremoves any high order bits ofrhsthat would cause the shift to exceed the bitwidth of the type.use WrappingShl; let x: u16 = 0x0001; assert_eq!; assert_eq!; assert_eq!; assert_eq!;
Implementors
impl WrappingShl for i8impl WrappingShl for i128impl WrappingShl for u32impl WrappingShl for i16impl<T: WrappingShl> WrappingShl for Wrapping<T>impl WrappingShl for u64impl WrappingShl for i32impl WrappingShl for usizeimpl WrappingShl for i64impl WrappingShl for u8impl WrappingShl for u128impl WrappingShl for isizeimpl WrappingShl for u16