Trait FromPrimitive
trait FromPrimitive: Sized
A generic trait for converting a number to a value.
A value can be represented by the target type when it lies within
the range of scalars supported by the target type.
For example, a negative integer cannot be represented by an unsigned
integer type, and an i64 with a very high magnitude might not be
convertible to an i32.
On the other hand, conversions with possible precision loss or truncation
are admitted, like an f32 with a decimal part to an integer type, or
even a large f64 saturating to f32 infinity.
Required Methods
fn from_i64(n: i64) -> Option<Self>Converts an
i64to return an optional value of this type. If the value cannot be represented by this type, thenNoneis returned.fn from_u64(n: u64) -> Option<Self>Converts an
u64to return an optional value of this type. If the value cannot be represented by this type, thenNoneis returned.
Provided Methods
fn from_isize(n: isize) -> Option<Self>Converts an
isizeto return an optional value of this type. If the value cannot be represented by this type, thenNoneis returned.fn from_i8(n: i8) -> Option<Self>Converts an
i8to return an optional value of this type. If the value cannot be represented by this type, thenNoneis returned.fn from_i16(n: i16) -> Option<Self>Converts an
i16to return an optional value of this type. If the value cannot be represented by this type, thenNoneis returned.fn from_i32(n: i32) -> Option<Self>Converts an
i32to return an optional value of this type. If the value cannot be represented by this type, thenNoneis returned.fn from_i128(n: i128) -> Option<Self>Converts an
i128to return an optional value of this type. If the value cannot be represented by this type, thenNoneis returned.The default implementation converts through
from_i64(). Types implementing this trait should override this method if they can represent a greater range.fn from_usize(n: usize) -> Option<Self>Converts a
usizeto return an optional value of this type. If the value cannot be represented by this type, thenNoneis returned.fn from_u8(n: u8) -> Option<Self>Converts an
u8to return an optional value of this type. If the value cannot be represented by this type, thenNoneis returned.fn from_u16(n: u16) -> Option<Self>Converts an
u16to return an optional value of this type. If the value cannot be represented by this type, thenNoneis returned.fn from_u32(n: u32) -> Option<Self>Converts an
u32to return an optional value of this type. If the value cannot be represented by this type, thenNoneis returned.fn from_u128(n: u128) -> Option<Self>Converts an
u128to return an optional value of this type. If the value cannot be represented by this type, thenNoneis returned.The default implementation converts through
from_u64(). Types implementing this trait should override this method if they can represent a greater range.fn from_f32(n: f32) -> Option<Self>Converts a
f32to return an optional value of this type. If the value cannot be represented by this type, thenNoneis returned.fn from_f64(n: f64) -> Option<Self>Converts a
f64to return an optional value of this type. If the value cannot be represented by this type, thenNoneis returned.The default implementation tries to convert through
from_i64(), and failing that throughfrom_u64(). Types implementing this trait should override this method if they can represent a greater range.
Implementors
impl FromPrimitive for u8impl FromPrimitive for u16impl FromPrimitive for u32impl FromPrimitive for u64impl FromPrimitive for u128impl FromPrimitive for f32impl FromPrimitive for f64impl<T: FromPrimitive> FromPrimitive for Wrapping<T>impl FromPrimitive for isizeimpl FromPrimitive for i8impl FromPrimitive for i16impl FromPrimitive for i32impl FromPrimitive for i64impl FromPrimitive for i128impl FromPrimitive for usize