Trait PrimInt
trait PrimInt: Sized + Copy + Num + NumCast + Bounded + PartialOrd + Ord + Eq + Not<Output = Self> + BitAnd<Output = Self> + BitOr<Output = Self> + BitXor<Output = Self> + Shl<usize, Output = Self> + Shr<usize, Output = Self> + CheckedAdd<Output = Self> + CheckedSub<Output = Self> + CheckedMul<Output = Self> + CheckedDiv<Output = Self> + Saturating
Generic trait for primitive integers.
The PrimInt trait is an abstraction over the builtin primitive integer types (e.g., u8,
u32, isize, i128, ...). It inherits the basic numeric traits and extends them with
bitwise operators and non-wrapping arithmetic.
The trait explicitly inherits Copy, Eq, Ord, and Sized. The intention is that all
types implementing this trait behave like primitive types that are passed by value by default
and behave like builtin integers. Furthermore, the types are expected to expose the integer
value in binary representation and support bitwise operators. The standard bitwise operations
(e.g., bitwise-and, bitwise-or, right-shift, left-shift) are inherited and the trait extends
these with introspective queries (e.g., PrimInt::count_ones(), PrimInt::leading_zeros()),
bitwise combinators (e.g., PrimInt::rotate_left()), and endianness converters (e.g.,
PrimInt::to_be()).
All PrimInt types are expected to be fixed-width binary integers. The width can be queried
via T::zero().count_zeros(). The trait currently lacks a way to query the width at
compile-time.
While a default implementation for all builtin primitive integers is provided, the trait is in no way restricted to these. Other integer types that fulfil the requirements are free to implement the trait was well.
This trait and many of the method names originate in the unstable core::num::Int trait from
the rust standard library. The original trait was never stabilized and thus removed from the
standard library.
Required Methods
fn count_ones(self: Self) -> u32Returns the number of ones in the binary representation of
self.Examples
use PrimInt; let n = 0b01001100u8; assert_eq!;fn count_zeros(self: Self) -> u32Returns the number of zeros in the binary representation of
self.Examples
use PrimInt; let n = 0b01001100u8; assert_eq!;fn leading_zeros(self: Self) -> u32Returns the number of leading zeros in the binary representation of
self.Examples
use PrimInt; let n = 0b0101000u16; assert_eq!;fn trailing_zeros(self: Self) -> u32Returns the number of trailing zeros in the binary representation of
self.Examples
use PrimInt; let n = 0b0101000u16; assert_eq!;fn rotate_left(self: Self, n: u32) -> SelfShifts the bits to the left by a specified amount,
n, wrapping the truncated bits to the end of the resulting integer.Examples
use PrimInt; let n = 0x0123456789ABCDEFu64; let m = 0x3456789ABCDEF012u64; assert_eq!;fn rotate_right(self: Self, n: u32) -> SelfShifts the bits to the right by a specified amount,
n, wrapping the truncated bits to the beginning of the resulting integer.Examples
use PrimInt; let n = 0x0123456789ABCDEFu64; let m = 0xDEF0123456789ABCu64; assert_eq!;fn signed_shl(self: Self, n: u32) -> SelfShifts the bits to the left by a specified amount,
n, filling zeros in the least significant bits.This is bitwise equivalent to signed
Shl.Examples
use PrimInt; let n = 0x0123456789ABCDEFu64; let m = 0x3456789ABCDEF000u64; assert_eq!;fn signed_shr(self: Self, n: u32) -> SelfShifts the bits to the right by a specified amount,
n, copying the "sign bit" in the most significant bits even for unsigned types.This is bitwise equivalent to signed
Shr.Examples
use PrimInt; let n = 0xFEDCBA9876543210u64; let m = 0xFFFFEDCBA9876543u64; assert_eq!;fn unsigned_shl(self: Self, n: u32) -> SelfShifts the bits to the left by a specified amount,
n, filling zeros in the least significant bits.This is bitwise equivalent to unsigned
Shl.Examples
use PrimInt; let n = 0x0123456789ABCDEFi64; let m = 0x3456789ABCDEF000i64; assert_eq!;fn unsigned_shr(self: Self, n: u32) -> SelfShifts the bits to the right by a specified amount,
n, filling zeros in the most significant bits.This is bitwise equivalent to unsigned
Shr.Examples
use PrimInt; let n = -8i8; // 0b11111000 let m = 62i8; // 0b00111110 assert_eq!;fn swap_bytes(self: Self) -> SelfReverses the byte order of the integer.
Examples
use PrimInt; let n = 0x0123456789ABCDEFu64; let m = 0xEFCDAB8967452301u64; assert_eq!;fn from_be(x: Self) -> SelfConvert an integer from big endian to the target's endianness.
On big endian this is a no-op. On little endian the bytes are swapped.
Examples
use PrimInt; let n = 0x0123456789ABCDEFu64; if cfg! elsefn from_le(x: Self) -> SelfConvert an integer from little endian to the target's endianness.
On little endian this is a no-op. On big endian the bytes are swapped.
Examples
use PrimInt; let n = 0x0123456789ABCDEFu64; if cfg! elsefn to_be(self: Self) -> SelfConvert
selfto big endian from the target's endianness.On big endian this is a no-op. On little endian the bytes are swapped.
Examples
use PrimInt; let n = 0x0123456789ABCDEFu64; if cfg! elsefn to_le(self: Self) -> SelfConvert
selfto little endian from the target's endianness.On little endian this is a no-op. On big endian the bytes are swapped.
Examples
use PrimInt; let n = 0x0123456789ABCDEFu64; if cfg! elsefn pow(self: Self, exp: u32) -> SelfRaises self to the power of
exp, using exponentiation by squaring.Examples
use PrimInt; assert_eq!;
Provided Methods
fn leading_ones(self: Self) -> u32Returns the number of leading ones in the binary representation of
self.Examples
use PrimInt; let n = 0xF00Du16; assert_eq!;fn trailing_ones(self: Self) -> u32Returns the number of trailing ones in the binary representation of
self.Examples
use PrimInt; let n = 0xBEEFu16; assert_eq!;fn reverse_bits(self: Self) -> SelfReverses the order of bits in the integer.
The least significant bit becomes the most significant bit, second least-significant bit becomes second most-significant bit, etc.
Examples
use PrimInt; let n = 0x12345678u32; let m = 0x1e6a2c48u32; assert_eq!; assert_eq!;
Implementors
impl PrimInt for i128impl PrimInt for isizeimpl PrimInt for u8impl PrimInt for u16impl PrimInt for u32impl PrimInt for u64impl PrimInt for u128impl PrimInt for usizeimpl PrimInt for i8impl PrimInt for i16impl PrimInt for i32impl PrimInt for i64