Trait OverflowingAdd

trait OverflowingAdd: Sized + Add<Self, Output = Self>

Performs addition with a flag for overflow.

Required Methods

fn overflowing_add(self: &Self, v: &Self) -> (Self, bool)

Returns a tuple of the sum along with a boolean indicating whether an arithmetic overflow would occur. If an overflow would have occurred then the wrapped value is returned.

Implementors