Trait OverflowingMul
trait OverflowingMul: Sized + Mul<Self, Output = Self>
Performs multiplication with a flag for overflow.
Required Methods
fn overflowing_mul(self: &Self, v: &Self) -> (Self, bool)Returns a tuple of the product along with a boolean indicating whether an arithmetic overflow would occur. If an overflow would have occurred then the wrapped value is returned.
Implementors
impl OverflowingMul for u8impl OverflowingMul for u128impl OverflowingMul for isizeimpl OverflowingMul for u16impl OverflowingMul for i8impl OverflowingMul for i128impl OverflowingMul for u32impl OverflowingMul for i16impl OverflowingMul for u64impl OverflowingMul for i32impl OverflowingMul for usizeimpl OverflowingMul for i64