Trait Bounded

trait Bounded

Numbers which have upper and lower bounds

Required Methods

fn min_value() -> Self

Returns the smallest finite number this type can represent

fn max_value() -> Self

Returns the largest finite number this type can represent

Implementors