Trait CheckedShl
trait CheckedShl: Sized + Shl<u32, Output = Self>
Performs a left shift that returns None on shifts larger than
or equal to the type width.
Required Methods
fn checked_shl(self: &Self, rhs: u32) -> Option<Self>Checked shift left. Computes
self << rhs, returningNoneifrhsis larger than or equal to the number of bits inself.use CheckedShl; let x: u16 = 0x0001; assert_eq!; assert_eq!; assert_eq!; assert_eq!;
Implementors
impl CheckedShl for u64impl CheckedShl for i32impl CheckedShl for usizeimpl CheckedShl for i64impl CheckedShl for u8impl CheckedShl for u128impl CheckedShl for isizeimpl CheckedShl for u16impl CheckedShl for i8impl CheckedShl for i128impl CheckedShl for u32impl CheckedShl for i16