Trait CheckedShr
trait CheckedShr: Sized + Shr<u32, Output = Self>
Performs a right shift that returns None on shifts larger than
or equal to the type width.
Required Methods
fn checked_shr(self: &Self, rhs: u32) -> Option<Self>Checked shift right. Computes
self >> rhs, returningNoneifrhsis larger than or equal to the number of bits inself.use CheckedShr; let x: u16 = 0x8000; assert_eq!; assert_eq!; assert_eq!; assert_eq!;
Implementors
impl CheckedShr for u8impl CheckedShr for u128impl CheckedShr for isizeimpl CheckedShr for u16impl CheckedShr for i8impl CheckedShr for i128impl CheckedShr for u32impl CheckedShr for i16impl CheckedShr for u64impl CheckedShr for i32impl CheckedShr for usizeimpl CheckedShr for i64