Trait NumRef
trait NumRef: Num + for<'r> NumOps<&'r Self>
The trait for Num types which also implement numeric operations taking
the second operand by reference.
This is automatically implemented for types which implement the operators.
Implementors
impl<T> NumRef for T